# Changelog

## 0.0.2 (2026-01-16)

Full Changelog: [v0.0.1...v0.0.2](https://github.com/evrimai/evrim-python/compare/v0.0.1...v0.0.2)

### Chores

* update SDK settings ([70d79c1](https://github.com/evrimai/evrim-python/commit/70d79c1c2d66ab30c4f28269c18279633a000c99))
* update SDK settings ([433ff03](https://github.com/evrimai/evrim-python/commit/433ff0327de2a2d7607d947aceb00ef357ee95e6))
